@@ -1,5 +1,6 @@
 from pwn import *
 from . import extract_shellcode
+from colorama import Fore,Back,Style
 
 '''
 11.10 add powerpc reverse backdoor
@@ -85,27 +86,43 @@ def powerpc_backdoor(reverse_ip, reverse_port, filename = None):
 	sc
 	'''
 	shellcode = asm(shellcode%(handle_port, handle_ip_0, handle_ip_1, handle_ip_2, handle_ip_3))
-	data = make_elf(shellcode)
+	ELF_data = make_elf(shellcode)
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
 		f=open("./powerpc_backdoor","wb")
-		f.write(data)
+		f.write(ELF_data)
 		f.close()
 		log.success("powerpc_backdoor is ok in current path ./")
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
 	else:
-		log.info("waiting 3s")
-		sleep(1)
-		f=open(filename,"wb")
-		f.write(data)
-		f.close()
-		log.success("{} is ok in current path ./".format(filename))
-		context.arch='i386'
-		context.bits="32"
-		context.endian="little"
+		if(os.path.exists(filename) != True):
+			log.info("waiting 3s")
+			sleep(1)
+			f=open(filename,"wb")
+			f.write(ELF_data)
+			f.close()
+			log.success("{} generated successfully".format(filename))
+			context.arch='i386'
+			context.bits="32"
+			context.endian="little"
+		else:
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			choise = input()
+			if choise == "y\n" or choise == "\n":
+				log.info("waiting 3s")
+				sleep(1)
+				f=open(filename,"wb")
+				f.write(ELF_data)
+				f.close()
+				log.success("{} generated successfully".format(filename))
+				context.arch='i386'
+				context.bits="32"
+				context.endian="little"
+			else:
+				return 
 
 
 def ppc_reverse_sl(reverse_ip, reverse_port, filename = None):
@@ -493,27 +510,43 @@ def powerpcle_backdoor(reverse_ip, reverse_port, filename=None):
 	sc
 	'''
 	shellcode = asm(shellcode % (handle_port_2,handle_port_1, handle_ip_0, handle_ip_2, handle_ip_2, handle_ip_3))
-	data = make_elf(shellcode)
+	ELF_data = make_elf(shellcode)
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
 		f=open("./powerpcle_backdoor","wb")
-		f.write(data)
+		f.write(ELF_data)
 		f.close()
 		log.success("powerpcle_backdoor is ok in current path ./")
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
 	else:
-		log.info("waiting 3s")
-		sleep(1)
-		f=open(filename,"wb")
-		f.write(data)
-		f.close()
-		log.success("{} is ok in current path ./".format(filename))
-		context.arch='i386'
-		context.bits="32"
-		context.endian="little"
+		if(os.path.exists(filename) != True):
+			log.info("waiting 3s")
+			sleep(1)
+			f=open(filename,"wb")
+			f.write(ELF_data)
+			f.close()
+			log.success("{} generated successfully".format(filename))
+			context.arch='i386'
+			context.bits="32"
+			context.endian="little"
+		else:
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			choise = input()
+			if choise == "y\n" or choise == "\n":
+				log.info("waiting 3s")
+				sleep(1)
+				f=open(filename,"wb")
+				f.write(ELF_data)
+				f.close()
+				log.success("{} generated successfully".format(filename))
+				context.arch='i386'
+				context.bits="32"
+				context.endian="little"
+			else:
+				return 
 
 '''
 pwoerpc64 reverse_shell_file 
@@ -597,27 +630,43 @@ def powerpc64_backdoor(reverse_ip, reverse_port, filename=None):
 	#print(shellcode%(handle_port, handle_ip_0, handle_ip_1, handle_ip_2, handle_ip_3))
 	shellcode = asm(shellcode%(handle_port, handle_ip_0, handle_ip_1, handle_ip_2, handle_ip_3))
 	#print(shellcode)
-	data = make_elf(shellcode)
+	ELF_data = make_elf(shellcode)
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
 		f=open("./powerpc64_backdoor","wb")
-		f.write(data)
+		f.write(ELF_data)
 		f.close()
 		log.success("powerpc64_backdoor is ok in current path ./")
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
 	else:
-		log.info("waiting 3s")
-		sleep(1)
-		f=open(filename,"wb")
-		f.write(data)
-		f.close()
-		log.success("{} is ok in current path ./".format(filename))
-		context.arch='i386'
-		context.bits="32"
-		context.endian="little"
+		if(os.path.exists(filename) != True):
+			log.info("waiting 3s")
+			sleep(1)
+			f=open(filename,"wb")
+			f.write(ELF_data)
+			f.close()
+			log.success("{} generated successfully".format(filename))
+			context.arch='i386'
+			context.bits="32"
+			context.endian="little"
+		else:
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			choise = input()
+			if choise == "y\n" or choise == "\n":
+				log.info("waiting 3s")
+				sleep(1)
+				f=open(filename,"wb")
+				f.write(ELF_data)
+				f.close()
+				log.success("{} generated successfully".format(filename))
+				context.arch='i386'
+				context.bits="32"
+				context.endian="little"
+			else:
+				return 
 
 
 '''
@@ -704,27 +753,43 @@ def powerpc64le_backdoor(reverse_ip, reverse_port, filename=None):
 	#shellcode = asm(shellcode%(handle_port, handle_ip_3, handle_ip_2, handle_ip_1, handle_ip_0))
 	shellcode = asm(shellcode%(handle_port_2 , handle_port_1, handle_ip_0, handle_ip_2, handle_ip_2, handle_ip_3))
 	#print(shellcode)
-	data = make_elf(shellcode)
+	ELF_data = make_elf(shellcode)
 	if(filename==None):
 		log.info("waiting 3s")
 		sleep(1)
 		f=open("./powerpc64le_backdoor","wb")
-		f.write(data)
+		f.write(ELF_data)
 		f.close()
 		log.success("powerpc64le_backdoor is ok in current path ./")
 		context.arch = 'i386'
 		context.bits = "32"
 		context.endian = "little"
 	else:
-		log.info("waiting 3s")
-		sleep(1)
-		f=open(filename,"wb")
-		f.write(data)
-		f.close()
-		log.success("{} is ok in current path ./".format(filename))
-		context.arch='i386'
-		context.bits="32"
-		context.endian="little"
+		if(os.path.exists(filename) != True):
+			log.info("waiting 3s")
+			sleep(1)
+			f=open(filename,"wb")
+			f.write(ELF_data)
+			f.close()
+			log.success("{} generated successfully".format(filename))
+			context.arch='i386'
+			context.bits="32"
+			context.endian="little"
+		else:
+			print(Fore.RED+"[+]"+" be careful File existence may overwrite the file (y/n) ",end='')
+			choise = input()
+			if choise == "y\n" or choise == "\n":
+				log.info("waiting 3s")
+				sleep(1)
+				f=open(filename,"wb")
+				f.write(ELF_data)
+				f.close()
+				log.success("{} generated successfully".format(filename))
+				context.arch='i386'
+				context.bits="32"
+				context.endian="little"
+			else:
+				return 
 
 def ppc64_reverse_sl(reverse_ip, reverse_port, filename=None):
 	context.arch = 'powerpc64'
@@ -823,4 +888,4 @@ def ppc64_reverse_sl(reverse_ip, reverse_port, filename=None):
 		context.arch='i386'
 		context.bits="32"
 		context.endian="little"
-		return shellcode
\ No newline at end of file
+		return shellcode
